package App::wget::retry;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2020-07-13'; # DATE
our $DIST = 'App-wget-retry'; # DIST
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Wget wrapper to retry harder

__END__

=pod

=encoding UTF-8

=head1 NAME

App::wget::retry - Wget wrapper to retry harder

=head1 VERSION

This document describes version 0.003 of App::wget::retry (from Perl distribution App-wget-retry), released on 2020-07-13.

=head1 SYNOPSIS

See included script L<wget-retry>.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-wget-retry>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-wget-retry>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-wget-retry>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
